from sqlalchemy import Table, Column, ForeignKey, Integer, String, Text, DateTime, Boolean
from sqlalchemy.orm import relationship, mapper

from mapwocgui.model.meta import Base, metadata

from mapwoc.lib.url import URL, URLList

# M:N Relational Table.
urllist_url = Table('urllist_url', metadata,
                    Column('urllist_id', ForeignKey('urllist.id')),
                    Column('url_id', Integer, ForeignKey('url.id')))

# URL Table.
url_table = Table('url', metadata,
                  Column('id', Integer, primary_key=True),
                  Column('url', String, nullable=False))

# URL-List Table
urllist_table = Table('urllist', metadata,
                      Column('id', Integer, primary_key=True),
                      Column('name', String, nullable=False),
                      Column('comment', Text, nullable=True),
                      Column('date', DateTime, nullable=True),
                      Column('deleted', Boolean, nullable=True))

# The Mappers
mapper(URL, url_table)

urllist_map_properties = {'urls':relationship(URL, secondary=urllist_url,
                                              backref='urllist')}
mapper(URLList, urllist_table, properties=urllist_map_properties)

