import logging
import ConfigParser
from StringIO import StringIO

from pylons import request, response, session, tmpl_context as c, url
from pylons.controllers.util import abort, redirect

from mapwocgui.lib.base import BaseController, render
import mapwocgui.lib.helpers as h

import mapwocgui.model.masterproxy as master

log = logging.getLogger(__name__)

class NodeController(BaseController):

    def index(self):

        # Get node-table
        c.masterproxy_nodes = master.get_nodes()
        c.nodeconfs = master.get_node_confs()
        nodeconfs_io = StringIO(c.nodeconfs)
        c.node_conf_parser = ConfigParser.ConfigParser()
        c.node_conf_parser.readfp(nodeconfs_io)
        c.nodestates = {}
        for nodekey in c.node_conf_parser.sections():
            c.nodestates[nodekey] = master.get_node_state(nodekey)
        return render('node/index_node.mako')
        
    def view(self, id):
        # TODO sometimes, connection errors are interesting (e.g. for querying state),
        #      sometimes they are a real error (getting details of an non-existing nodectrl,
        #      dead master). Deal with it.
        try:
            c.hcs = master.get_hcs() 
            stateset = master.get_state_set()
            c.nodestate = stateset.get('nodes').get(id)
            if c.nodestate is None:
                c.nodestate = {}
                c.nodestate[''] = 'Unreachable'
                c.node_runlist = []
            else:
                c.node_runlist = c.nodestate.get('runlist')
            c.nodename = id
        except IOError:
            pass

        return render('node/view_node.mako')

    def start_hc(self, id, dst):
        """Start a hc(id) on a node(dst)."""

        master.start_hc(id, dst)
        response.status_int = 302
        response.headers['location'] = h.url_for(controller='node',action='view',id=dst)
        return 'id: ' + id + " dst: " + dst

    def stopallhcs(self, id):
        master.stop_hc("abc", id)
        response.status_int = 302
        response.headers['location'] = h.url_for(controller='node',action='view',id=id)
        return 'stop all'

    def sync(self, id):
        master.sync_hcs()
        response.status_int = 302
        response.headers['location'] = h.url_for(controller='node',action='view',id=id)
        return 'stop all'

